Learn R Programming

ggthemeUL (version 0.1.3)

ul_color: University of Ljubljana colors

Description

This function provides a set of color schemes adhering to the official visual identity of the University of Ljubljana. If no arguments are supplied, it returns all available colors. If specific color names are supplied, it will return only those colors.

Usage

ul_color(...)

Value

A character vector of hexadecimal color codes. If no arguments are supplied, all color codes are returned. If specific color names are supplied, only the color codes for those colors are returned.

Arguments

...

Optional character vectors. If color names are supplied, only those colors will be returned. If no arguments are supplied, all available colors are returned. Avaiable colors are red, antracit, medium, lajt, darkblue, navyblue, turquoise, green, yellow, orange, burgundy, and pink.

Examples

Run this code
ul_color("red", "green") # Returns hexadecimal color codes for red and green
ul_color() # Returns all available colors

Run the code above in your browser using DataLab