Learn R Programming

ggthemeUL (version 0.1.3)

ul_pal: University of Ljubljana color palettes

Description

This function provides color palettes adhering to the official visual identity of the University of Ljubljana. It includes the primary and secondary palettes, individual color gradations, and multiple divergent color palettes.

Usage

ul_pal(palette = "primary", neutralColor = "white", reverse = FALSE, ...)

Value

A function that takes an integer argument n and returns a character vector of n colors.

Arguments

palette

Character. The name of the palette to use.

  • Primary: "primary" (default)

  • Secondary (cold): "secondaryCold"

  • Secondary (warm): "secondaryWarm"

  • Individual colors: "red", "antracit", "medium", "lajt", "darkblue", "navyblue", "turquoise", "green", "yellow", "orange", "burgundy", "pink"

  • Divergent: "redBlue", "redGreen", "blueTurquise", "blueYellow"

neutralColor

Define the color used as neutral (default "white").

reverse

Logical. If TRUE, reverses the order of colors in the palette. Default is FALSE.

...

Additional arguments to be passed to the colorRampPalette function.

Examples

Run this code
pal <- ul_pal("redBlue", reverse = TRUE)
pal(7)  # Generates a reversed divergent palette of 7 colors

Run the code above in your browser using DataLab