powered by
This function provides color palettes adhering to the official visual identity of the University of Ljubljana. It includes the primary and secondary palettes, individual color gradations, and multiple divergent color palettes.
ul_pal(palette = "primary", neutralColor = "white", reverse = FALSE, ...)
A function that takes an integer argument n and returns a character vector of n colors.
Character. The name of the palette to use.
Primary: "primary" (default)
"primary"
Secondary (cold): "secondaryCold"
"secondaryCold"
Secondary (warm): "secondaryWarm"
"secondaryWarm"
Individual colors: "red", "antracit", "medium", "lajt", "darkblue", "navyblue", "turquoise", "green", "yellow", "orange", "burgundy", "pink"
"red"
"antracit"
"medium"
"lajt"
"darkblue"
"navyblue"
"turquoise"
"green"
"yellow"
"orange"
"burgundy"
"pink"
Divergent: "redBlue", "redGreen", "blueTurquise", "blueYellow"
"redBlue"
"redGreen"
"blueTurquise"
"blueYellow"
Define the color used as neutral (default "white").
"white"
Logical. If TRUE, reverses the order of colors in the palette. Default is FALSE.
TRUE
FALSE
Additional arguments to be passed to the colorRampPalette function.
colorRampPalette
pal <- ul_pal("redBlue", reverse = TRUE) pal(7) # Generates a reversed divergent palette of 7 colors
Run the code above in your browser using DataLab